@@ -21,18 +21,40 @@
 
 static char rcsid[] = "$Id: disable-paste.c,v 1.2 2000/01/17 22:23:03 rubini Exp $";
 
-#include <unistd.h>             /* execv */
-
-static char* argv[] = {
-  "gpm",
-  "-A",
-  "-q",
-  0 
-};
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <ctype.h>
+#include <unistd.h>
+#include <fcntl.h>
+#include <signal.h>
+#include <sys/types.h>
+#include <sys/time.h>
+#include <unistd.h>
+#include <termios.h>
+#include <errno.h>
+#include "gpm.h"
+#include "gpmInt.h"
 
 int 
-main()
+main(int argc, char** argv)
 {
-  execv(SBINDIR "/gpm", argv);
-  exit(127);
+  Gpm_Connect conn;
+  const int len = sizeof(Gpm_Connect);
+  int exit_status = 0;
+  conn.eventMask = (unsigned short)(-1); conn.defaultMask = 0;
+  conn.minMod = 0; conn.maxMod = (unsigned short)(-1);
+  
+  if (0 > Gpm_Open(&conn,0)) {
+    fprintf(stderr,"disable-paste: cannot open mouse connection\n");
+    exit(1);
+  }
+  conn.vc = GPM_REQ_NOPASTE;
+  conn.pid = 0;
+  if (len > write(gpm_fd, &conn, len)) {
+    fprintf(stderr,"disable-paste: cannot write request\n");
+    exit_status = 2;
+  }
+  Gpm_Close();
+  exit(exit_status);
 }
