@@ -69,7 +69,6 @@ struct mouse_features *which_mouse;
 
 /* These are only the 'global' options */
 
-int opt_quit=0;
 char *opt_lut=DEF_LUT;
 int opt_test=DEF_TEST;
 int opt_ptrdrag=DEF_PTRDRAG;
@@ -658,26 +657,11 @@ static int get_data(Gpm_Connect *where, int whence)
   return 1;
 }
 
-/* itz Sat Sep 12 20:46:51 PDT 1998 this used to be shared with
-   gpn.c.  Mixing apples and oranges. */
-
 static void
-xfer_options(int fd)
+disable_paste(int vc)
 {
-  Opt_struct_type opts;
-  struct mouse_features *which_mouse=mouse_table+1; /* local */
-
-  read(fd,&opts,sizeof(opts));
-  opt_accel=opts.a;
-  sprintf(opt_sequence,"%08d",opts.B);
-  opt_delta=opts.d;
-  opt_time=opts.i; opt_ptrdrag=opts.p; opt_scale=opts.r;
-  gpm_debug_level = opts.V;
-  opt_aged = opts.A;
-  gpm_debug_log(LOG_INFO,"got %i,%i,%i,%i,%i,%i,%i,%i", opt_accel, opts.B,
-                opt_delta, opt_time, opt_ptrdrag, opt_scale,
-                gpm_debug_level, opt_aged);
-  kill(getpid(),SIGWINCH); /* update delta's */
+  opt_aged++;
+  gpm_debug_log(LOG_INFO,"disabling pasting per request from tty%d", vc);
 }
 
 /*-------------------------------------------------------------------*/
@@ -760,8 +744,8 @@ static inline int processRequest(Gpm_Cinfo *ci, int vc)
       write(ci->fd,&event,sizeof(Gpm_Event));
       break;
 
-    case GPM_REQ_CONFIG:
-      xfer_options(ci->fd);
+    case GPM_REQ_NOPASTE:
+      disable_paste(vc);
       break;
     }
 
@@ -807,6 +791,7 @@ static inline int processConn(int fd) /* returns newfd or -1 */
   if (get_data(request,newfd)==-1)
     {
     free(info);
+    close(newfd);
     return -1;
     }
 
@@ -814,13 +799,16 @@ static inline int processConn(int fd) /* returns newfd or -1 */
     {
     gpm_debug_log(LOG_WARNING,"Request on vc %i > %i", vc, MAX_VC);
     free(info);
+    close(newfd);
     return -1;
   }
 
+#ifndef SO_PEERCRED
   if (stat (addr.sun_path, &statbuf) == -1 ||
       !S_ISSOCK(statbuf.st_mode)) {
     gpm_debug_log (LOG_ERR, "Address %s not a socket in processConn",addr.sun_path);
     free(info);			/* itz 10-12-95 verify client's right */
+    close(newfd);
     return -1;			/* to read requested tty */
   } /*if*/
   
@@ -832,20 +820,38 @@ static inline int processConn(int fd) /* returns newfd or -1 */
       || statbuf.st_mtime < staletime) {
     gpm_debug_log (LOG_ERR, "Socket too old in processConn");
     free (info);
+    close(newfd);
     return -1;			/* socket is ancient */
   } /*if*/
   
   uid = statbuf.st_uid;		/* owner of socket */
+#else
+  {
+    struct ucred sucred;
+    socklen_t credlen = sizeof(struct ucred);
+
+    if (-1 == getsockopt(newfd, SOL_SOCKET, SO_PEERCRED, &sucred, &credlen)) {
+      gpm_debug_log(LOG_ERR,"getsockopt(SO_PEERCRED): %s", strerror(errno));
+      free(info);
+      close(newfd);
+      return -1;
+    }
+    uid = sucred.uid;
+    gpm_debug_log(LOG_DEBUG,"peer socket uid = %d", uid);
+  }
+#endif
   if (uid != 0) {
     sprintf (tty, "/dev/tty%d", vc);
     if (-1 == stat (tty, &statbuf)) {
       gpm_debug_log (LOG_ERR, "stat on %s fails in processConn", tty);
       free (info);
+      close(newfd);
       return -1;
     } /*if*/
     if (uid != statbuf.st_uid) {
-      gpm_debug_log (LOG_WARNING, "Failed gpm connect attempt by uid %d", uid); /* SUSPECT!! */
+      gpm_debug_log (LOG_WARNING, "Failed gpm connect attempt by uid %d for %s", uid, tty); /* SUSPECT!! */
       free (info);
+      close(newfd);
       return -1;
     } /*if*/    
   } /*if*/
@@ -932,11 +938,15 @@ int main(int argc, char **argv)
   Gpm_Event event;
 
   prgname=argv[0];
-  setuid(0); /* just in case... */
+
 
 /*....................................... parse command line */
 
   cmdline(argc, argv);
+  if (0 != geteuid()) {
+    fputs("sorry, gpm has to run as root\n",stderr);
+    exit(1);
+  } /* just in case... */
   atexit(gpm_exited);
 
   for (i=1; i <= 1+opt_double; i++)
