@@ -44,6 +44,7 @@
 #define GPM_REQ_SNAPSHOT 0
 #define GPM_REQ_BUTTONS  1
 #define GPM_REQ_CONFIG   2
+#define GPM_REQ_NOPASTE  3
 
 /*....................................... Structures */
 
@@ -117,7 +118,6 @@ typedef struct Opt_struct_type {int a,B,d,i,p,r,V,A;} Opt_struct_type;
 /* the other variables */
 
 extern char *prgname;
-extern int opt_quit;
 extern char *opt_lut;
 extern int opt_test, opt_ptrdrag;
 extern int opt_kill;
