@@ -136,39 +136,6 @@ static int loadlut(char *charset)
   return 0;
 }
 
-/*===================================================================*
- * This function transfers "-a -B -p -i -l -p -r" to a running server.
- *-------------------------------------------------------------------*/
-static int 
-xfer_options(void)
-{
-  Opt_struct_type opts;
-  struct mouse_features *which_mouse=mouse_table+1; /* local */
-  Gpm_Connect fake; 
-  char *tty;
-  int fd;
-  
-  fake.minMod = fake.maxMod = fake.eventMask = fake.defaultMask = 0;
-  opts.a=opt_accel; sscanf(opt_sequence,"%d",&opts.B); opts.d=opt_delta;
-  opts.i=opt_time; opts.p=opt_ptrdrag; opts.r=opt_scale;
-  opts.V = gpm_debug_level; opts.A = opt_aged;
-
-  tty=ttyname(0); /* stdin */
-  if (!tty) oops("ttyname()");
-  if (strncmp(tty,"/dev/tty",8) || !isdigit(tty[8]))
-    {fprintf(stderr,"%s: %s: not a virtual console\n",prgname,tty);exit(1);}
-
-  if (-1 == (fd = Gpm_Open(&fake, -1))) {
-    oops("Gpm_Open()");
-  } /*if*/
-  
-  fake.pid = 0; fake.vc = GPM_REQ_CONFIG;
-  write(fd,&fake,sizeof(Gpm_Connect));
-  write(fd,&opts,sizeof(opts));
-  Gpm_Close();
-  return 0;
-}
-
 /*===================================================================*/
 static int
 usage(char *whofailed)
@@ -319,7 +286,7 @@ static struct Gpm_Type *find_mouse_by_name(char *name)
 int 
 cmdline(int argc, char **argv)
 {
-  char options[]="a:A::b:B:d:Dg:hi:kl:m:Mo:pqr:R::s:S:t:TvV::23";
+  char options[]="a:A::b:B:d:Dg:hi:kl:m:Mo:pr:R::s:S:t:TvV::23";
   int i, opt;
   static struct {char *in; char *out;} seq[] = {
     {"123","01234567"},
@@ -359,7 +326,6 @@ cmdline(int argc, char **argv)
         case 'i': opt_time=atoi(optarg); break;
         case 'k': opt_kill++; gpm_log_daemon = 0; break;
         case 'l': opt_lut=optarg; break;
-        case 'L': opt_lut=optarg; opt_quit++; break;
         case 'm': opt_dev = optarg; break;
         case 'M':
           opt_double++;
@@ -369,7 +335,6 @@ cmdline(int argc, char **argv)
           which_mouse=mouse_table+2; break;
 	case 'o': opt_options = optarg; break;
         case 'p': opt_ptrdrag=0; break;
-        case 'q': opt_quit++; gpm_log_daemon = 0; break;
         case 'r':
 	  /* being called responsiveness, I must take the inverse */
 	  opt_scale=atoi(optarg);
@@ -405,10 +370,8 @@ cmdline(int argc, char **argv)
   openlog(prgname, LOG_PID, gpm_log_daemon ? LOG_DAEMON : LOG_USER);
   check_kill();
 
-  if (!opt_quit) 
-    {
-      loadlut(opt_lut);
-    }
+  loadlut(opt_lut);
+
   if (opt_repeater)
     {
       if (mkfifo(GPM_NODE_FIFO,0666) && errno!=EEXIST)
@@ -462,12 +425,6 @@ cmdline(int argc, char **argv)
     } /*if*/
   } /*if*/
 
-  /* now we can put the options */
-  if (opt_quit) {
-    int st = xfer_options();
-    exit(st);
-  } /*if*/
-
   if (gpm_log_daemon) {         /* itz Wed Aug 12 15:44:37 PDT 1998 */
                                 /* now a runtime option */
 
